
collect clear
collect style clear
collect style use default

use nhanessp2, clear
table región, statistic(percent)

* percentages across another categorical variable
table salud región, statistic(percent, across(salud))

* percentages for multiple variables across region
table (var) (región), ///
 statistic(fvpercent diabetes alta ataque) ///
 style(table-1) sformat("%s%%")

* percentages and means for continuous variables, like age 
table (var) (región), statistic(mean presión imc edad) ///
 statistic(fvpercent ataque alta diabetes) ///
 style(table-1) nformat(%6.2f mean) sformat("%s%%" fvpercent)

ttest presión, by(sexo)
return list

table (command) (result), ///
 command(Hombres=r(mu_1) Mujeres=r(mu_2) Diferencia=r(mu_2)-r(mu_1) r(p): ttest presión, by(sexo)) ///
 command(Hombres=r(mu_1) Mujeres=r(mu_2) Diferencia=r(mu_2)-r(mu_1) r(p): ttest colesterol, by(sexo)) nformat(%6.2f) nformat(%05.4f p) 
 
collect label levels command 1 "Presión arterial sistólica" 2 "Colesterol", modify
collect label levels result p "Valor p", modify
collect preview 

table región , statistic(mean presión imc)
table () región, statistic(mean presión imc)

collect dims

collect style header var, level(value)
collect preview

collect style cell cell_type[column-header item], halign(center)
collect style cell border_block[row-header corner], border(right, pattern(nil))
collect preview 

collect export tabla1.html, replace 

**************************************

collect create reg1 
use nhanessp, clear
collect: regress presión peso i.diabetes

return list
matrix list r(table)

collect layout (colname) (result)

collect dims

collect layout (colname) (result[_r_b _r_ci])

collect: regress presión peso diabetes##sexo

collect dims

collect layout (colname) (cmdset#result[_r_b _r_ci])

collect layout (colname#result[_r_b _r_se]) (cmdset)

collect layout (colname#result[_r_b _r_se] result[r2]) (cmdset)

collect style showbase off
collect style cell result, nformat(%5.2f) 
collect preview 

collect style cell result[_r_se], sformat("(%s)")
collect preview

collect levelsof cell_type
collect style cell cell_type[item column-header], halign(center)
collect style cell border_block[corner row-header], border(right, pattern(nil))
collect preview

collect label list result 
collect style header result, level(hide)
collect style header result[r2], level(label)
collect preview

collect style column, extraspace(1)
collect style row stack, delimiter(" x ") spacer
collect preview

collect export report1.xlsx, replace 

**************** Creating a standard look

collect style save tablareg, replace 

collect dir 

collect create reg2

collect _r_b _r_se: regress colesterol i.diabetes i.sexo
collect _r_b _r_se: regress colesterol diabetes##sexo

collect layout (colname#result) (cmdset)

collect style use tablareg, replace layout
collect preview 

collect stars _r_p 0.01 "***" 0.05 "** " 0.10 "*  ", attach(_r_b)
collect preview 

collect export report2.pdf, replace 


******** Combining results 

use nhanessp2, clear

collect create logit
logit alta i.sexo i.diabetes i.edadcat, nolog 

collect: margins sexo diabetes edadcat

table var if e(sample), stat(fvpercent sexo diabetes edadcat) ///
  name(logit) append
  
collect dims

collect layout (colname) (result[fvpercent _r_b _r_ci])

collect label levels result fvpercent "% Población" _r_b "Prob." _r_ci "95% CI", modify 
collect style row stack, nobinder
collect preview 

collect style cell result[_r_b _r_ci], nformat(%05.3f) halign(center)
collect style cell result[_r_ci], cidelimiter(", ") sformat("[%s]") 
collect style cell result[fvpercent], nformat(%5.2f) sformat("%s%%") halign(right)
collect style cell border_block[corner row-header], border(right, pattern(nil))
collect preview
************** final customized table of percentages and probabilities 

* Create a graph
graph bar (mean) presión, over(edadcat) ///
  asyvars legend(rows(2)) scheme(s1color) blabel(bar) ytitle("") ///
 title("Presión promedio")
graph export presion.png, replace 

* Create an active .docx file and insert the graph
putdocx begin 
putdocx paragraph, halign(center)
putdocx image presion.png, width(4.5)

* Specify the style to be used when exporting the table
collect style putdocx, width(80%) title(Probabilidad de tener la presión alta)      
putdocx collect 
putdocx save report3.docx, replace 

**************************



